@@ -17,6 +17,10 @@ class BaseScreen(IOverlayParent, Screen):
 	def trimmed(self, textRenderer: TextRenderer, str: StringVisitable, width: int) -> OrderedText:
 		pass
 
+	@overload
+	def setParent(self, parent: Screen) -> None:
+		pass
+
 	@overload
 	def reload(self) -> None:
 		pass
@@ -82,7 +86,7 @@ class BaseScreen(IOverlayParent, Screen):
 		pass
 
 	@overload
-	def onClose(self) -> None:
+	def close(self) -> None:
 		pass
 
 	@overload
