@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .MultiElementContainer import *
-from .IContainerParent import *
+from .MultiElementContainer import MultiElementContainer
+from .IContainerParent import IContainerParent
 
 Consumer = TypeVar["java.util.function.Consumer_java.lang.Boolean_"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
