@@ -2,10 +2,9 @@ from typing import overload
 from typing import TypeVar
 from typing import Mapping
 
-T = TypeVar["T"]
+T = TypeVar("T")
 JsonObject = TypeVar["com.google.gson.JsonObject"]
 Logger = TypeVar["org.apache.logging.log4j.Logger"]
-Map = TypeVar["java.util.Map_java.lang.Class__,java.lang.Object_"]
 File = TypeVar["java.io.File"]
 
 class ConfigManager:
