@@ -7,6 +7,7 @@ from .LibraryRegistry import LibraryRegistry
 from .BaseEventRegistry import BaseEventRegistry
 from .ConfigManager import ConfigManager
 from .BaseLanguage import BaseLanguage
+from .ServiceManager import ServiceManager
 from .EventContainer import EventContainer
 from .BaseScriptContext import BaseScriptContext
 from .ScriptTrigger import ScriptTrigger
@@ -30,6 +31,17 @@ class Core(Generic[T, U]):
 	config: ConfigManager
 	languages: List[BaseLanguage]
 	defaultLang: BaseLanguage
+	services: ServiceManager
+
+	@overload
+	def getInstance(self) -> "Core":
+		"""static reference to instance created by Core#<V,R>createInstance(java.util.function.Function<xyz.wagyourtail.jsmacros.core.Core<V,R>,R>,java.util.function.Function<xyz.wagyourtail.jsmacros.core.Core<V,R>,V>,java.io.File,java.io.File,org.apache.logging.log4j.Logger)
+		"""
+		pass
+
+	@overload
+	def deferredInit(self) -> None:
+		pass
 
 	@overload
 	def addContext(self, container: EventContainer) -> None:
