@@ -3,6 +3,7 @@ from typing import List
 from typing import TypeVar
 from typing import Mapping
 from .ScriptTrigger import ScriptTrigger
+from .ServiceTrigger import ServiceTrigger
 
 JsonObject = TypeVar["com.google.gson.JsonObject"]
 
@@ -10,6 +11,7 @@ class CoreConfigV2:
 	maxLockTime: float
 	defaultProfile: str
 	profiles: Mapping[str, List[ScriptTrigger]]
+	services: Mapping[str, ServiceTrigger]
 	extraJsOptions: Mapping[str, str]
 
 	@overload
