@@ -144,6 +144,23 @@ class Draw2D(IDraw2D, DrawableHelper):
 
 	@overload
 	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.4.0 
+		"""
+		pass
+
+	@overload
+	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
+	@overload
+	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.6.5 
+		"""
 		pass
 
 	@overload
@@ -287,6 +304,26 @@ clears all previous elements when called.\n
 		"""
 		pass
 
+	@overload
+	def register(self) -> "Draw2D":
+		"""register so the overlay actually renders\n
+		Since: 1.6.5 
+
+		Returns:
+			self for chaining 
+		"""
+		pass
+
+	@overload
+	def unregister(self) -> "Draw2D":
+		"""register so the overlay actually renders\n
+		Since: 1.6.5 
+
+		Returns:
+			self for chaining 
+		"""
+		pass
+
 	pass
 
 
