@@ -1,5 +1,5 @@
 from typing import overload
-from .Button import *
+from .Button import Button
 
 
 class EventChooser_EventObj:
