@@ -1,8 +1,11 @@
 from typing import overload
-from .BaseEvent import *
+from .BaseEvent import BaseEvent
 
 
 class EventKey(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	action: int
 	key: str
 	mods: str
@@ -17,10 +20,20 @@ class EventKey(BaseEvent):
 
 	@overload
 	def getKeyModifiers(self, mods: int) -> str:
+		"""turn an Integer for key modifiers into a Translation Key.
+
+		Args:
+			mods: 
+		"""
 		pass
 
 	@overload
 	def getModInt(self, mods: str) -> int:
+		"""turn a Translation Key for modifiers into an Integer .
+
+		Args:
+			mods: 
+		"""
 		pass
 
 	pass
