@@ -1,11 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .BaseEvent import *
-from .EntityHelper import *
+from .BaseEvent import BaseEvent
+from .EntityHelper import EntityHelper
 
 Entity = TypeVar["net.minecraft.entity.Entity"]
 
 class EventRiding(BaseEvent):
+	"""
+	Since: 1.5.0 
+	"""
 	state: bool
 	entity: EntityHelper
 
