@@ -1,12 +1,13 @@
 from typing import overload
 from typing import List
-from typing import TypeVar
-from .BaseEvent import *
-from .PositionCommon_Pos3D import *
+from .BaseEvent import BaseEvent
+from .PositionCommon_Pos3D import PositionCommon_Pos3D
 
-List = TypeVar["java.util.List_java.lang.String_"]
 
 class EventSignEdit(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	pos: PositionCommon_Pos3D
 	closeScreen: bool
 	signText: List[str]
