@@ -138,6 +138,15 @@ An instance of this class is passed to scripts as the 'Player' variable.
 	def createPlayerInput(self, movementForward: float, movementSideways: float, yaw: float, pitch: float, jumping: bool, sneaking: bool, sprinting: bool) -> PlayerInput:
 		"""Creates a new PlayerInput object.\n
 		Since: 1.4.0 
+
+		Args:
+			movementForward: 1 = forward input (W); 0 = no input; -1 = backward input (S) 
+			sprinting: sprint input 
+			jumping: jump input 
+			sneaking: sneak input 
+			pitch: pitch of the player 
+			yaw: yaw of the player 
+			movementSideways: 1 = left input (A); 0 = no input; -1 = right input (D) 
 		"""
 		pass
 
