@@ -8,11 +8,10 @@ KeyBinding = TypeVar["net.minecraft.client.option.KeyBinding"]
 Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
 MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]
 InputUtil_Key = TypeVar["net.minecraft.client.util.InputUtil.Key"]
-ClientModInitializer = TypeVar["net.fabricmc.api.ClientModInitializer"]
 Text = TypeVar["net.minecraft.text.Text"]
 Logger = TypeVar["org.apache.logging.log4j.Logger"]
 
-class JsMacros(ClientModInitializer):
+class JsMacros:
 	MOD_ID: str
 	LOGGER: Logger
 	keyBinding: KeyBinding
@@ -23,6 +22,10 @@ class JsMacros(ClientModInitializer):
 	def __init__(self) -> None:
 		pass
 
+	@overload
+	def onInitialize(self) -> None:
+		pass
+
 	@overload
 	def onInitializeClient(self) -> None:
 		pass
