@@ -2,6 +2,7 @@ from typing import overload
 from typing import TypeVar
 from .BaseScreen import BaseScreen
 from .ScriptTrigger import ScriptTrigger
+from .MultiElementContainer import MultiElementContainer
 from .MacroContainer import MacroContainer
 
 Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
@@ -23,7 +24,7 @@ class MacroScreen(BaseScreen):
 		pass
 
 	@overload
-	def setFile(self, macro: MacroContainer) -> None:
+	def setFile(self, macro: MultiElementContainer) -> None:
 		pass
 
 	@overload
@@ -35,11 +36,11 @@ class MacroScreen(BaseScreen):
 		pass
 
 	@overload
-	def confirmRemoveMacro(self, macro: MacroContainer) -> None:
+	def confirmRemoveMacro(self, macro: MultiElementContainer) -> None:
 		pass
 
 	@overload
-	def removeMacro(self, macro: MacroContainer) -> None:
+	def removeMacro(self, macro: MultiElementContainer) -> None:
 		pass
 
 	@overload
@@ -59,7 +60,7 @@ class MacroScreen(BaseScreen):
 		pass
 
 	@overload
-	def onClose(self) -> None:
+	def close(self) -> None:
 		pass
 
 	pass
