@@ -7,11 +7,16 @@ ClientWorld = TypeVar["net.minecraft.client.world.ClientWorld"]
 
 class MixinMinecraftClient:
 	currentScreen: Screen
+	interactionManager: ClientPlayerInteractionManager
 
 	@overload
 	def __init__(self) -> None:
 		pass
 
+	@overload
+	def setScreen(self, screen: Screen) -> None:
+		pass
+
 	@overload
 	def onJoinWorld(self, world: ClientWorld, info: CallbackInfo) -> None:
 		pass
@@ -21,7 +26,11 @@ class MixinMinecraftClient:
 		pass
 
 	@overload
-	def onDisconnect(self, info: CallbackInfo) -> None:
+	def afterOpenScreen(self, screen: Screen, info: CallbackInfo) -> None:
+		pass
+
+	@overload
+	def onDisconnect(self, s: Screen, info: CallbackInfo) -> None:
 		pass
 
 	pass
