@@ -71,6 +71,27 @@ class PlayerEntityHelper(Generic[T], LivingEntityHelper):
 		"""
 		pass
 
+	@overload
+	def getXPLevel(self) -> int:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
+	@overload
+	def getXPProgress(self) -> float:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
+	@overload
+	def getXPToLevelUp(self) -> int:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
 	@overload
 	def isSleeping(self) -> bool:
 		"""
