@@ -29,7 +29,7 @@ class ScoreboardsHelper(BaseHelper):
 
 	@overload
 	def getObjectiveSlot(self, slot: int) -> ScoreboardObjectiveHelper:
-		"""'0' is tablist, '1' or '3 + getPlayerTeamColorIndex()' is sidebar, '2' should be tab list.
+		"""'0' is tab list, '1' or '3 + getPlayerTeamColorIndex()' is sidebar, '2' should be below name.
 therefore max slot number is 18.\n
 		Since: 1.2.9 
 
@@ -48,6 +48,16 @@ therefore max slot number is 18.\n
 		"""
 		pass
 
+	@overload
+	def getPlayerTeamColorIndex(self) -> int:
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			team index for client player 
+		"""
+		pass
+
 	@overload
 	def getTeams(self) -> List[TeamHelper]:
 		"""
@@ -65,6 +75,16 @@ therefore max slot number is 18.\n
 		"""
 		pass
 
+	@overload
+	def getPlayerTeam(self) -> TeamHelper:
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			team for client player 
+		"""
+		pass
+
 	@overload
 	def getCurrentScoreboard(self) -> ScoreboardObjectiveHelper:
 		"""
