@@ -7,13 +7,14 @@ from .EditorScreen import EditorScreen
 from .AutoCompleteSuggestion import AutoCompleteSuggestion
 
 Runnable = TypeVar["java.lang.Runnable"]
+File = TypeVar["java.io.File"]
 
 class ScriptCodeCompiler(AbstractRenderCodeCompiler):
 	"""
 	"""
 
 	@overload
-	def __init__(self, language: str, screen: EditorScreen, scriptFile: str) -> None:
+	def __init__(self, language: str, screen: EditorScreen, scriptFile: File) -> None:
 		pass
 
 	@overload
