@@ -1,9 +1,9 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .ICategoryTreeParent import *
-from .OverlayContainer import *
-from .IOverlayParent import *
+from .ICategoryTreeParent import ICategoryTreeParent
+from .OverlayContainer import OverlayContainer
+from .IOverlayParent import IOverlayParent
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
