@@ -9,12 +9,13 @@ from .FRequest import FRequest
 from .FTime import FTime
 from .FKeyBind import FKeyBind
 from .FHud import FHud
-from .FFS import FFS
 from .FJsMacros import FJsMacros
+from .FFS import FFS
 from .FReflection import FReflection
 from .FClient import FClient
 from .FWorld import FWorld
 from .FGlobalVars import FGlobalVars
+from .FPositionCommon import FPositionCommon
 
 File = TypeVar["java.io.File"]
 
@@ -27,12 +28,13 @@ Request = FRequest()
 Time = FTime()
 KeyBind = FKeyBind()
 Hud = FHud()
-FS = FFS()
 JsMacros = FJsMacros()
+FS = FFS()
 Reflection = FReflection()
 Client = FClient()
 World = FWorld()
 GlobalVars = FGlobalVars()
+PositionCommon = FPositionCommon()
 context = EventContainer()
 file = File()
 event = BaseEvent()
